@@ -114,9 +114,12 @@ class FunctionData(Model):
     #: Use this code instead of the generated code
     cpp_code: Optional[str] = None
 
-    #: Docstring for the function
+    #: Docstring for the function, will attempt to convert Doxygen docs if omitted
     doc: Optional[str] = None
 
+    #: Text to append to the (autoconverted) docstring for the function
+    doc_append: Optional[str] = None
+
     #: If True, prepends an underscore to the python name
     internal: bool = False
 
@@ -218,6 +221,9 @@ class PropData(Model):
     #: Docstring for the property (only available on class properties)
     doc: Optional[str] = None
 
+    #: Text to append to the (autoconverted) docstring
+    doc_append: Optional[str] = None
+
 
 class EnumValue(Model):
 
@@ -230,12 +236,18 @@ class EnumValue(Model):
     #: Docstring for the enum value
     doc: Optional[str] = None
 
+    #: Text to append to the (autoconverted) docstring
+    doc_append: Optional[str] = None
+
 
 class EnumData(Model):
 
     #: Set your own docstring for the enum
     doc: Optional[str] = None
 
+    #: Text to append to the (autoconverted) docstring
+    doc_append: Optional[str] = None
+
     #: If set to True, this property is not made available to python
     ignore: bool = False
 
@@ -256,6 +268,9 @@ class ClassData(Model):
     #: Docstring for the class
     doc: Optional[str] = None
 
+    #: Text to append to the (autoconverted) docstring
+    doc_append: Optional[str] = None
+
     ignore: bool = False
     ignored_bases: List[str] = []
 
@@ -320,6 +335,10 @@ class ClassData(Model):
     #: into the template definition
     template_inline_code: str = ""
 
+    #: If this class has an associated trampoline, add this code inline at
+    #: the bottom of the trampoline class. This is rarely useful.
+    trampoline_inline_code: Optional[str] = None
+
     @validator("attributes", pre=True)
     def validate_attributes(cls, value):
         for k, v in value.items():
@@ -380,6 +399,12 @@ class TemplateData(Model):
     #: If specified, put the template instantiation in a sub.pack.age
     subpackage: Optional[str] = None
 
+    #: Set the docstring for the template instance
+    doc: Optional[str] = None
+
+    #: Text to append to the (autoconverted) docstring for the template instance
+    doc_append: Optional[str] = None
+
 
 class HooksDataYaml(Model):
     """
@@ -407,6 +432,9 @@ class HooksDataYaml(Model):
     #: * ``cls_CLASSNAME`` are ``py::class`` instances
     #: * ... lots of other things too
     #:
+    #: The trampoline class (useful for accessing protected items) is available
+    #: at ``{CLASSNAME}_Trampoline``
+    #:
     #: To see the full list, run a build and look at the generated code at
     #: ``build/*/gensrc/**/*.cpp``
     #:
